@@ -24,7 +24,7 @@ from yaml import load as yaml_load
 
 from .protocol import SUPPORT_SCHEMA
 from .utils import get_parent_tree, parse_value_string_by_schema, parse_schema_as_cmd
-from .entrypoint_base import SchemaType, EntryPointABC
+from .entrypoint_base import SchemaType, PropertyType, EntryPointABC
 
 
 class EntryPoint(EntryPointABC):
@@ -179,7 +179,15 @@ class EntryPoint(EntryPointABC):
             if self.epilog:
                 epilog = self.epilog
             else:
-                epilog = "子命令描述:\n" + "\n".join([f"{subcmd}\t{ins.__doc__}" for subcmd, ins in self._subcmds.items()])
+                epilog = "子命令描述:\n"
+                rows = []
+                for subcmd, ins in self._subcmds.items():
+                    if ins.__doc__ and isinstance(ins.__doc__, str):
+                        desc = ins.__doc__.splitlines()[0]
+                        rows.append(f"{subcmd}\t{desc}")
+                    else:
+                        rows.append(f"{subcmd}")
+                epilog += "\n".join(rows)
             parser = argparse.ArgumentParser(
                 prog=self.prog,
                 epilog=epilog,
@@ -211,7 +219,7 @@ class EntryPoint(EntryPointABC):
         if self.schema is None:
             raise AttributeError("此处不该被执行")
         else:
-            properties: Dict[str, Dict[str, Any]] = self.schema.get("properties", {})
+            properties: Dict[str, PropertyType] = self.schema.get("properties", {})
             requireds: List[str] = self.schema.get("required", [])
             for key, prop in properties.items():
                 required = False
@@ -249,10 +257,22 @@ class EntryPoint(EntryPointABC):
                 else:
                     continue
             else:
-                if value is not None:
-                    cmd_res.update({
-                        key: value
-                    })
+                try:
+                    if self.schema is not None and self.schema.get("properties") is not None:
+                        if self.schema["properties"].get(key) is not None and self.schema["properties"][key]["type"] == "boolean":
+                            if value is False:
+                                if self.schema.get("required") is None:
+                                    value = None
+                                else:
+                                    if key not in self.schema["required"]:
+                                        value = None
+                except Exception as e:
+                    warnings.warn(str(e))
+                finally:
+                    if value is not None:
+                        cmd_res.update({
+                            key: value
+                        })
         return config_file_res, cmd_res
 
     def parse_commandline_args(self, parser: argparse.ArgumentParser, argv: Sequence[str]) -> Tuple[Dict[str, Any], Dict[str, Any]]:
@@ -269,7 +289,7 @@ class EntryPoint(EntryPointABC):
         parser.add_argument("-c", "--config", type=str, help='指定配置文件位置')
         return self._parse_commandline_args_by_schema(parser, argv)
 
-    def _parse_env_args(self, key: str, info: Dict[str, Any]) -> Any:
+    def _parse_env_args(self, key: str, info: PropertyType) -> Any:
         if self.env_prefix:
             env_prefix = self.env_prefix.upper()
         else:
@@ -403,6 +423,16 @@ class EntryPoint(EntryPointABC):
         return {}
 
     def parse_args(self, parser: argparse.ArgumentParser, argv: Sequence[str]) -> None:
+        """解析获取配置
+
+        配置的加载顺序为: 指定路径的配置文件->环境变量->命令行参数
+
+        在加载完配置后校验是否满足schema的要求.
+
+        Args:
+            parser (argparse.ArgumentParser): 命令行参数解析器
+            argv (Sequence[str]): 命令行参数序列
+        """
         # 默认配置
         default_config = self.parse_default()
         self._config.update(default_config)
