@@ -26,7 +26,7 @@ SUPPORT_SCHEMA = {
                                     "type": "boolean",
                                 },
                                 "const": {
-                                    "type": "string"
+                                    "type": "boolean"
                                 },
                                 "description": {
                                     "type": "string"
@@ -206,7 +206,10 @@ SUPPORT_SCHEMA = {
                                             "enum": ["string", "number", "integer"]
                                         },
                                         "enum":{
-                                            "type": "array"
+                                            "type": "array",
+                                            "items": {
+                                                "type": ["string", "number", "integer"]
+                                            }
                                         }
                                     }
                                 },
